@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -12,8 +12,10 @@
 # language governing permissions and limitations under the License.
 
 from braket.ir.jaqcd.instructions import (  # noqa: F401
+    CV,
     CY,
     CZ,
+    ECR,
     XX,
     XY,
     YY,
@@ -28,11 +30,13 @@ from braket.ir.jaqcd.instructions import (  # noqa: F401
     CPhaseShift10,
     CSwap,
     Depolarizing,
+    EndVerbatimBox,
     GeneralizedAmplitudeDamping,
     H,
     I,
     ISwap,
     Kraus,
+    MultiQubitPauliChannel,
     PauliChannel,
     PhaseDamping,
     PhaseFlip,
@@ -43,6 +47,7 @@ from braket.ir.jaqcd.instructions import (  # noqa: F401
     Rz,
     S,
     Si,
+    StartVerbatimBox,
     Swap,
     T,
     Ti,
