@@ -12,6 +12,12 @@
 # language governing permissions and limitations under the License
 
 from braket.task_result.additional_metadata import AdditionalMetadata  # noqa: F401
+from braket.task_result.analog_hamiltonian_simulation_task_result_v1 import (  # noqa: F401
+    AnalogHamiltonianSimulationShotMeasurement,
+    AnalogHamiltonianSimulationShotMetadata,
+    AnalogHamiltonianSimulationShotResult,
+    AnalogHamiltonianSimulationTaskResult,
+)
 from braket.task_result.annealing_task_result_v1 import AnnealingTaskResult  # noqa: F401
 from braket.task_result.dwave_metadata_v1 import DwaveMetadata, DwaveTiming  # noqa: F401
 from braket.task_result.gate_model_task_result_v1 import (  # noqa: F401
@@ -20,6 +26,7 @@ from braket.task_result.gate_model_task_result_v1 import (  # noqa: F401
 )
 from braket.task_result.oqc_metadata_v1 import OqcMetadata  # noqa: F401
 from braket.task_result.photonic_model_task_result_v1 import PhotonicModelTaskResult  # noqa: F401
+from braket.task_result.quera_metadata_v1 import QueraMetadata  # noqa: F401
 from braket.task_result.rigetti_metadata_v1 import NativeQuilMetadata, RigettiMetadata  # noqa: F401
 from braket.task_result.simulator_metadata_v1 import SimulatorMetadata  # noqa: F401
 from braket.task_result.task_metadata_v1 import TaskMetadata  # noqa: F401
